@@ -36,8 +36,6 @@
 #define DEFAULT_TIMEOUT 4
 #endif
 
-#define NANOS_PER_SECONDS 1000000000
-
 int check_major_version = CHECK_MAJOR_VERSION;
 int check_minor_version = CHECK_MINOR_VERSION;
 int check_micro_version = CHECK_MICRO_VERSION;
@@ -253,30 +251,28 @@ void _mark_point (const char *file, int line)
   send_loc_info (file, line);
 }
 
-void _ck_assert_msg (int result, const char *file,
+void _ck_assert_failed (const char *file,
                    int line, const char *expr, ...)
 {
   const char *msg;
-    
+  va_list ap;
+  char buf[BUFSIZ];
+
   send_loc_info (file, line);
-  if (!result) {
-    va_list ap;
-    char buf[BUFSIZ];
-    
-    va_start(ap,expr);
-    msg = (const char*)va_arg(ap, char *);
-    if (msg == NULL)
-      msg = expr;
-    vsnprintf(buf, BUFSIZ, msg, ap);
-    va_end(ap);
-    send_failure_info (buf);
-    if (cur_fork_status() == CK_FORK) {
-#ifdef HAVE_FORK
-      exit(1);
-#endif /* HAVE_FORK */
-    } else {
-      longjmp(error_jmp_buffer, 1);
-    }
+
+  va_start(ap,expr);
+  msg = (const char*)va_arg(ap, char *);
+  if (msg == NULL)
+    msg = expr;
+  vsnprintf(buf, BUFSIZ, msg, ap);
+  va_end(ap);
+  send_failure_info (buf);
+  if (cur_fork_status() == CK_FORK) {
+  #if defined(HAVE_FORK) && HAVE_FORK==1
+    exit(1);
+  #endif /* HAVE_FORK */
+  } else {
+    longjmp(error_jmp_buffer, 1);
   }
 }
 
@@ -291,6 +287,7 @@ SRunner *srunner_create (Suite *s)
   sr->resultlst = check_list_create();
   sr->log_fname = NULL;
   sr->xml_fname = NULL;
+  sr->tap_fname = NULL;
   sr->loglst = NULL;
 
 #if defined(HAVE_FORK)
@@ -331,9 +328,7 @@ void srunner_free (SRunner *sr)
   l = sr->resultlst;
   for (check_list_front(l); !check_list_at_end(l); check_list_advance(l)) {
     tr = check_list_val(l);
-    free(tr->file);
-    free(tr->msg);
-    free(tr);
+    tr_free(tr);
   }
   check_list_free (sr->resultlst);
 
@@ -396,11 +391,6 @@ TestResult *tr_create(void)
   return tr;
 }
 
-void tr_reset(TestResult *tr)
-{
-  tr_init(tr);
-}
-
 static void tr_init (TestResult *tr)
 {
   tr->ctx = CK_CTX_INVALID;
@@ -413,6 +403,13 @@ static void tr_init (TestResult *tr)
   tr->duration = -1;
 }
 
+void tr_free(TestResult *tr)
+{
+  free(tr->file);
+  free(tr->msg);
+  free(tr);
+}
+
 
 const char *tr_msg (TestResult *tr)
 {
