@@ -5,6 +5,15 @@
 #define TIMEOUT_TESTS_ENABLED 1
 #endif
 
+/*
+ * Certain unit tests are known to leak memory. This
+ * #define will prevent those unit tests from being built
+ * if the program is to be used against valgrind.
+ */
+#ifndef MEMORY_LEAKING_TESTS_ENABLED
+#define MEMORY_LEAKING_TESTS_ENABLED 1
+#endif
+
 int sub_nfailed;
 int sub_ntests;
 
@@ -26,8 +35,9 @@ Suite *make_fork_suite(void);
 Suite *make_fixture_suite(void);
 Suite *make_pack_suite(void);
 Suite *make_exit_suite(void);
+Suite *make_selective_suite(void);
 
 extern int master_tests_lineno[];
-void init_master_tests_lineno(void);
+void init_master_tests_lineno(int num_master_tests);
 
 #endif /* CHECK_CHECK_H */
